@@ -665,8 +665,8 @@ def generate_random_correl_matrix(size: int, corr_max: float):
     mat = np.ndarray([size, size])
     res = pd.DataFrame(mat)
     for col in range(size):
-        mat.iloc[col, :] = np.random.uniform(-corr_max, corr_max, size)
-        mat.iloc[col, col] = 1
+        res.iloc[col, :] = np.random.uniform(-corr_max, corr_max, size)
+        res.iloc[col, col] = 1
     return res
 
 
