@@ -1,17 +1,15 @@
 import pandas as pd
 import os
 import numpy as np
-import math
+# import math
 
-from sklearn.decomposition import NMF
-
-from adlinear import pca
+# from adlinear import pca
 from adlinear import utilities as utl
 from adlinear import nmfmodel as nmf
-from adlinear import testers as tst
+# from adlinear import testers as tst
 from adlinear import imputer as imp
 from adlinear import clusterizer as clu
-from adlinear import ntfmodel as ntf
+# from adlinear import ntfmodel as ntf
 from randomgenerators import randomgenerators as rng
 
 import root_path
@@ -243,13 +241,13 @@ if __name__ == "__main__":
         rnd_norms = False
         # eps = np.random.uniform(low=0.0, high=0.25)
         eps = 0.0
-        generated_M = rng.generate_nmf_reconstruction(n_comp=nb_clusters,
-                                                      min_intra_corr=min_corr,
-                                                      max_inter_corr=max_corr,
-                                                      h_avg_clust_size=h_avg_csize,
-                                                      w_avg_clust_size=w_avg_csize,
-                                                      epsilon=eps,
-                                                      random_norms=rnd_norms)
+        gen_M = rng.generate_nmf_reconstruction(n_comp=nb_clusters,
+                                                min_intra_corr=min_corr,
+                                                max_inter_corr=max_corr,
+                                                h_avg_clust_size=h_avg_csize,
+                                                w_avg_clust_size=w_avg_csize,
+                                                epsilon=eps,
+                                                random_norms=rnd_norms)
         imp_nmf_proxy = imp.Imputer(method="nmf.proxy",
                                     params={"ncomp": 3,
                                             "nblocks": 1,
@@ -264,7 +262,7 @@ if __name__ == "__main__":
         imputers = [[imp_nmf_proxy, None],
                     [imp_nmf_proxy_pgrad, None]]
         imp_name = "RandomBlockMatrices_2"
-        imp_tester = imp.ImputerTester(mat=generated_M, name=f"{imp_name}_nc{nb_clusters}",
+        imp_tester = imp.ImputerTester(mat=gen_M, name=f"{imp_name}_nc{nb_clusters}",
                                        imputer=imp_nmf_proxy, ref_clst=None,
                                        clst=None, err_func="MSE")
         for imp in imputers:
@@ -278,10 +276,6 @@ if __name__ == "__main__":
         imp_tester.output_results(out_data_path)
 
     if os.getenv("imp_do_screeplot_tests", "False").lower() == "true":
-        # wh_name = os.getenv("imp_wh_matname")
-        # wh_mat = pd.read_csv(data_path / wh_name)
-        # wh_mat.drop(wh_mat.columns[0], axis='columns')
-        # wh_screeplot = nmf.generate_scree_plot(wh_mat, 2, 20)
 
         nb_clusters = 10
         min_corr = 0.9
@@ -290,34 +284,56 @@ if __name__ == "__main__":
         w_avg_csize = 20
         eps = 0
         random_norms = True
+        censor_rate = 0.0
+        gen_m, gen_w, gen_h, gen_noise = rng.generate_nmf_reconstruction(n_comp=nb_clusters,
+                                                                         min_intra_corr=min_corr,
+                                                                         max_inter_corr=max_corr,
+                                                                         h_avg_clust_size=h_avg_csize,
+                                                                         w_avg_clust_size=w_avg_csize,
+                                                                         epsilon=eps,
+                                                                         random_norms=random_norms)
+        utl.censor_data(mat=gen_m, p=censor_rate, inplace=True)
+        rnstr = "RandNorms" if random_norms else "ConstNorms"
+        wh_name = f"M_nc{nb_clusters}_corrmin{round(min_corr,2)}_" \
+                  f"corrmax{round(max_corr,2)}_noise{round(eps,2)}_{rnstr}_mis{censor_rate}.csv"
+        gen_m.to_csv(res_path / "random_nmf" / wh_name,
+                     float_format="%.4f")
+        df_scree_plot = nmf.generate_scree_plot(gen_m, ncmin=6, ncmax=12)
+        df_scree_plot.to_csv(res_path / f"{wh_name}_screeplot.csv")
         censor_rate = 0.01
-        read_wh_mat = True
+        read_wh_mat = (os.getenv("imp_read_whmat", "True").lower() == "true")
         rnstr = "RandNorms" if random_norms else "ConstNorms"
 
-        for censor_rate in [0.0, 0.01, 0.05, 0.10]:
+        censor_rates = [0.0]
+        for censor_rate in censor_rates:
 
             if read_wh_mat:
                 fixed_mat_name = os.getenv("imp_wh_matname")
                 rad_name = fixed_mat_name.split(".csv")[0]
                 wh_name = f"{rad_name}_mis{censor_rate}.csv"
                 # wh_name = "M_nc10_corrmin0.9_corrmax0.1_noise0_RandNorms_mis0.0.csv"
-                generated_M = pd.read_csv(data_path / fixed_mat_name, index_col=0)
+                gen_M = pd.read_csv(data_path / fixed_mat_name, index_col=0)
+                gen_w = pd.read_csv(data_path / f"w_{fixed_mat_name}", index_col=0)
+                gen_h = pd.read_csv(data_path / f"h_{fixed_mat_name}", index_col=0)
             else:
                 wh_name = f"M_nc{nb_clusters}_corrmin{round(min_corr, 2)}_" \
                           f"corrmax{round(max_corr, 2)}_noise{round(eps, 2)}_{rnstr}_mis{censor_rate}.csv"
-                generated_M = rng.generate_nmf_reconstruction(n_comp=nb_clusters,
-                                                              min_intra_corr=min_corr,
-                                                              max_inter_corr=max_corr,
-                                                              h_avg_clust_size=h_avg_csize,
-                                                              w_avg_clust_size=w_avg_csize,
-                                                              epsilon=eps,
-                                                              random_norms=random_norms)
+                gen_M, gen_w, gen_h, _ = rng.generate_nmf_reconstruction(n_comp=nb_clusters,
+                                                                         min_intra_corr=min_corr,
+                                                                         max_inter_corr=max_corr,
+                                                                         h_avg_clust_size=h_avg_csize,
+                                                                         w_avg_clust_size=w_avg_csize,
+                                                                         epsilon=eps,
+                                                                         random_norms=random_norms)
 
-            utl.censor_data(mat=generated_M, p=censor_rate, inplace=True)
-
-            generated_M.to_csv(res_path / "random_nmf" / wh_name,
-                               float_format="%.4f")
-            df_scree_plot = nmf.generate_scree_plot(generated_M, ncmin=6, ncmax=30)
+            utl.censor_data(mat=gen_M, p=censor_rate, inplace=True)
+            gen_M.to_csv(res_path / "random_nmf" / wh_name,
+                         float_format="%.4f")
+            gen_w.to_csv(res_path / "random_nmf" / f"W_{wh_name}",
+                         float_format="%.4f")
+            gen_h.to_csv(res_path / "random_nmf" / f"H_{wh_name}",
+                         float_format="%.4f")
+            df_scree_plot = nmf.generate_scree_plot(gen_M, ncmin=6, ncmax=30)
             df_scree_plot.to_csv(res_path / f"{wh_name}_screeplot.csv")
 
     if os.getenv("imp_do_ecodata_gans", "False").lower() == "true":
